==> fake-bpy-module-2.79-20221006.tar.gz: fake-bpy-module-2.79-20221006/bpy/app/handlers.py <==
import sys
import typing

GenericType = typing.TypeVar("GenericType")
frame_change_post = None
''' on frame change for playback and rendering (after)
'''

frame_change_pre = None
''' on frame change for playback and rendering (before)
'''

game_post = None
''' on ending the game engine
'''

game_pre = None
''' on starting the game engine
'''

load_post = None
''' on loading a new blend file (after)
'''

load_pre = None
''' on loading a new blend file (before)
'''

persistent = None
''' Function decorator for callback functions not to be removed when loading new files
'''

render_cancel = None
''' on canceling a render job
'''

render_complete = None
''' on completion of render job
'''

render_init = None
''' on initialization of a render job
'''

render_post = None
''' on render (after)
'''

render_pre = None
''' on render (before)
'''

render_stats = None
''' on printing render statistics
'''

render_write = None
''' on writing a render frame (directly after the frame is written)
'''

save_post = None
''' on saving a blend file (after)
'''

save_pre = None
''' on saving a blend file (before)
'''

scene_update_post = None
''' on every scene data update. Does not imply that anything changed in the scene, just that the dependency graph was reevaluated, and the scene was possibly updated by Blender's animation system.
'''

scene_update_pre = None
''' on every scene data update. Does not imply that anything changed in the scene, just that the dependency graph is about to be reevaluated, and the scene is about to be updated by Blender's animation system.
'''

version_update = None
''' on ending the versioning code
'''

==> fake-bpy-module-2.81-20210304.tar.gz: fake-bpy-module-2.81-20210304/bpy/app/handlers.py <==
import sys
import typing
depsgraph_update_post = None
''' on depsgraph update (post)
'''

depsgraph_update_pre = None
''' on depsgraph update (pre)
'''

frame_change_post = None
''' on frame change for playback and rendering (after)
'''

frame_change_pre = None
''' on frame change for playback and rendering (before)
'''

load_factory_preferences_post = None
''' on loading factory preferences (after)
'''

load_factory_startup_post = None
''' on loading factory startup (after)
'''

load_post = None
''' on loading a new blend file (after)
'''

load_pre = None
''' on loading a new blend file (before)
'''

persistent = None
''' Function decorator for callback functions not to be removed when loading new files
'''

redo_post = None
''' on loading a redo step (after)
'''

redo_pre = None
''' on loading a redo step (before)
'''

render_cancel = None
''' on canceling a render job
'''

render_complete = None
''' on completion of render job
'''

render_init = None
''' on initialization of a render job
'''

render_post = None
''' on render (after)
'''

render_pre = None
''' on render (before)
'''

render_stats = None
''' on printing render statistics
'''

render_write = None
''' on writing a render frame (directly after the frame is written)
'''

save_post = None
''' on saving a blend file (after)
'''

save_pre = None
''' on saving a blend file (before)
'''

undo_post = None
''' on loading an undo step (after)
'''

undo_pre = None
''' on loading an undo step (before)
'''

version_update = None
''' on ending the versioning code
'''
